# pypowerup

[![Version](https://img.shields.io/pypi/v/pypowerup.svg)](https://pypi.python.org/pypi/pypowerup)
[![Build Status](https://img.shields.io/travis/sophiamyang/pypowerup.svg)](https://travis-ci.org/sophiamyang/pypowerup)
[![Docs](https://readthedocs.org/projects/pypowerup/badge/?version=latest)](https://pypowerup.readthedocs.io/en/latest/?badge=latest)


``pypowerup`` is the Python implementation for the research article "PowerUp!: A Tool for Calculating Minimum Detectable 
Effect Sizes and Minimum Required Sample Sizes for Experimental and Quasi-experimental Design Studies (Dong & Maynard, 2013)". It is a 
power analysis tool for experimental and quasi-experimental designs.



References
-------
Dong, N. & Maynard, R. A. (2013). PowerUp!: A tool for calculating minimum detectable
effect sizes and minimum required sample sizes for experimental and quasi- experimental design studies, Journal of Research on Educational Effectiveness, 6(1), 24-67. doi: 10.1080/19345747.2012.673143.
https://www.causalevaluation.org/uploads/7/3/3/6/73366257/powerup.xlsm

Bulus, M., Dong, N., Kelcey, B., & Spybrook, J. (2019). PowerUpR: Power Analysis Tools for Multilevel Randomized Experiments. R package version 1.0.4. https://CRAN.R-project.org/package=PowerUpR